@@ -233,8 +233,9 @@ def _validate_auto_complete_callback(
     binding = getattr(callback, '__self__', None)
     if binding is not None:
         callback = callback.__func__
-
-    requires_binding = (binding is None and is_inside_class(callback)) or skip_binding
+        requires_binding = True
+    else:
+        requires_binding = is_inside_class(callback) or skip_binding
 
     callback.requires_binding = requires_binding
     callback.binding = binding
@@ -376,7 +377,7 @@ def _extract_parameters_from_callback(func: Callable[..., Any], globalns: Dict[s
     parameters: List[CommandParameter] = []
     for parameter in iterator:
         if parameter.annotation is parameter.empty:
-            raise TypeError(f'annotation for {parameter.name} must be given in callback {func.__qualname__!r}')
+            raise TypeError(f'parameter {parameter.name!r} is missing a type annotation in callback {func.__qualname__!r}')
 
         resolved = resolve_annotation(parameter.annotation, globalns, globalns, cache)
         param = annotation_to_parameter(resolved, parameter)
@@ -425,7 +426,7 @@ def _get_context_menu_parameter(func: ContextMenuCallback) -> Tuple[str, Any, Ap
     if len(params) != 2:
         msg = (
             f'context menu callback {func.__qualname__!r} requires 2 parameters, '
-            'the first one being the annotation and the other one explicitly '
+            'the first one being the interaction and the other one explicitly '
             'annotated with either discord.Message, discord.User, discord.Member, '
             'or a typing.Union of discord.Member and discord.User'
         )
@@ -815,10 +816,10 @@ class Command(Generic[GroupT, P, T]):
         .. code-block:: python3
 
             @app_commands.command()
-            async def fruits(interaction: discord.Interaction, fruits: str):
-                await interaction.response.send_message(f'Your favourite fruit seems to be {fruits}')
+            async def fruits(interaction: discord.Interaction, fruit: str):
+                await interaction.response.send_message(f'Your favourite fruit seems to be {fruit}')
 
-            @fruits.autocomplete('fruits')
+            @fruits.autocomplete('fruit')
             async def fruits_autocomplete(
                 interaction: discord.Interaction,
                 current: str,
@@ -1762,11 +1763,11 @@ def autocomplete(**parameters: AutocompleteCallback[GroupT, ChoiceT]) -> Callabl
     .. code-block:: python3
 
             @app_commands.command()
-            @app_commands.autocomplete(fruits=fruits_autocomplete)
-            async def fruits(interaction: discord.Interaction, fruits: str):
-                await interaction.response.send_message(f'Your favourite fruit seems to be {fruits}')
+            @app_commands.autocomplete(fruit=fruit_autocomplete)
+            async def fruits(interaction: discord.Interaction, fruit: str):
+                await interaction.response.send_message(f'Your favourite fruit seems to be {fruit}')
 
-            async def fruits_autocomplete(
+            async def fruit_autocomplete(
                 interaction: discord.Interaction,
                 current: str,
             ) -> List[app_commands.Choice[str]]:
